@@ -49,7 +49,7 @@ describe 'apache::mod::pagespeed class', if:   ((fact('operatingsystem') == 'Cen
       it { is_expected.to contain 'ModPagespeedForbidFilters rewrite_javascript' }
     end
 
-    it 'answers to pagespeed.example.com and include <head/> and be stripped of comments by mod_pagespeed' do # rubocop:disable RSpec/MultipleExpectations
+    it 'answers to pagespeed.example.com and include <head/> and be stripped of comments by mod_pagespeed' do
       shell('/usr/bin/curl pagespeed.example.com:80') do |r|
         expect(r.stdout).to match(%r{head\/})
         expect(r.stdout).not_to match(%r{<!-- comment -->})
