@@ -10,12 +10,11 @@ describe 'apache::dev', type: :class do
   context 'on a Debian OS' do
     let :facts do
       {
-        lsbdistcodename: 'squeeze',
+        lsbdistcodename: 'jessie',
         osfamily: 'Debian',
         operatingsystem: 'Debian',
         operatingsystemrelease: '6',
         is_pe: false,
-        concat_basedir: '/foo',
         id: 'root',
         path: '/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin',
         kernel: 'Linux',
@@ -27,16 +26,15 @@ describe 'apache::dev', type: :class do
     it { is_expected.to contain_package('libapr1-dev') }
     it { is_expected.to contain_package('apache2-prefork-dev') }
   end
-  context 'on an Ubuntu 14 OS' do
+  context 'on an Ubuntu 16 OS' do
     let :facts do
       {
-        lsbdistrelease: '14.04',
-        lsbdistcodename: 'trusty',
+        lsbdistrelease: '16.04',
+        lsbdistcodename: 'xenial',
         osfamily: 'Debian',
         operatingsystem: 'Ubuntu',
-        operatingsystemrelease: '14.04',
+        operatingsystemrelease: '16.04',
         is_pe: false,
-        concat_basedir: '/foo',
         id: 'root',
         path: '/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin',
         kernel: 'Linux',
@@ -52,7 +50,6 @@ describe 'apache::dev', type: :class do
         operatingsystem: 'RedHat',
         operatingsystemrelease: '6',
         is_pe: false,
-        concat_basedir: '/foo',
         id: 'root',
         path: '/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin',
         kernel: 'Linux',
@@ -69,7 +66,6 @@ describe 'apache::dev', type: :class do
         operatingsystem: 'FreeBSD',
         operatingsystemrelease: '9',
         is_pe: false,
-        concat_basedir: '/foo',
         id: 'root',
         path: '/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin',
         kernel: 'FreeBSD',
@@ -85,7 +81,6 @@ describe 'apache::dev', type: :class do
         operatingsystem: 'Gentoo',
         operatingsystemrelease: '3.16.1-gentoo',
         is_pe: false,
-        concat_basedir: '/foo',
         id: 'root',
         path: '/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin',
         kernel: 'Linux',
