@@ -7,10 +7,9 @@ describe 'apache::mod::authnz_pam', type: :class do
     context 'on a Debian OS' do
       let :facts do
         {
-          lsbdistcodename: 'squeeze',
+          lsbdistcodename: 'jessie',
           osfamily: 'Debian',
-          operatingsystemrelease: '6',
-          concat_basedir: '/dne',
+          operatingsystemrelease: '8',
           id: 'root',
           kernel: 'Linux',
           operatingsystem: 'Debian',
@@ -28,8 +27,7 @@ describe 'apache::mod::authnz_pam', type: :class do
       let :facts do
         {
           osfamily: 'RedHat',
-          operatingsystemrelease: '6',
-          concat_basedir: '/dne',
+          operatingsystemrelease: '8',
           id: 'root',
           kernel: 'Linux',
           operatingsystem: 'RedHat',
