@@ -7,13 +7,12 @@ describe 'apache::mod::dir', type: :class do
     let :facts do
       {
         osfamily: 'Debian',
-        operatingsystemrelease: '6',
-        concat_basedir: '/dne',
+        operatingsystemrelease: '8',
         operatingsystem: 'Debian',
         id: 'root',
         kernel: 'Linux',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
-        lsbdistcodename: 'squeeze',
+        lsbdistcodename: 'jessie',
         is_pe: false,
       }
     end
@@ -43,7 +42,6 @@ describe 'apache::mod::dir', type: :class do
       {
         osfamily: 'RedHat',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         operatingsystem: 'Redhat',
         id: 'root',
         kernel: 'Linux',
@@ -77,7 +75,6 @@ describe 'apache::mod::dir', type: :class do
       {
         osfamily: 'FreeBSD',
         operatingsystemrelease: '9',
-        concat_basedir: '/dne',
         operatingsystem: 'FreeBSD',
         id: 'root',
         kernel: 'FreeBSD',
@@ -112,7 +109,6 @@ describe 'apache::mod::dir', type: :class do
         osfamily: 'Gentoo',
         operatingsystem: 'Gentoo',
         operatingsystemrelease: '3.16.1-gentoo',
-        concat_basedir: '/dne',
         id: 'root',
         kernel: 'Linux',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/opt/bin',
