@@ -13,8 +13,7 @@ describe 'apache::mod::mime_magic', type: :class do
       {
         osfamily: 'Debian',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
-        lsbdistcodename: 'squeeze',
+        lsbdistcodename: 'jessie',
         operatingsystem: 'Debian',
         id: 'root',
         kernel: 'Linux',
@@ -58,7 +57,6 @@ describe 'apache::mod::mime_magic', type: :class do
       {
         osfamily: 'RedHat',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         operatingsystem: 'RedHat',
         id: 'root',
         kernel: 'Linux',
@@ -83,8 +81,7 @@ describe 'apache::mod::mime_magic', type: :class do
       {
         osfamily: 'Debian',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
-        lsbdistcodename: 'squeeze',
+        lsbdistcodename: 'jessie',
         operatingsystem: 'Debian',
         id: 'root',
         kernel: 'Linux',
