@@ -7,7 +7,6 @@ describe 'apache::mod::ssl', type: :class do
       {
         osfamily: 'Magic',
         operatingsystemrelease: '0',
-        concat_basedir: '/dne',
         operatingsystem: 'Magic',
         id: 'root',
         kernel: 'Linux',
@@ -25,7 +24,6 @@ describe 'apache::mod::ssl', type: :class do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '6',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -44,7 +42,6 @@ describe 'apache::mod::ssl', type: :class do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '6',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -68,7 +65,6 @@ describe 'apache::mod::ssl', type: :class do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -95,9 +91,8 @@ describe 'apache::mod::ssl', type: :class do
     let :facts do
       {
         osfamily: 'Debian',
-        operatingsystemrelease: '6',
-        concat_basedir: '/dne',
-        lsbdistcodename: 'squeeze',
+        operatingsystemrelease: '8',
+        lsbdistcodename: 'jessie',
         operatingsystem: 'Debian',
         id: 'root',
         kernel: 'Linux',
@@ -116,7 +111,6 @@ describe 'apache::mod::ssl', type: :class do
       {
         osfamily: 'FreeBSD',
         operatingsystemrelease: '9',
-        concat_basedir: '/dne',
         operatingsystem: 'FreeBSD',
         id: 'root',
         kernel: 'FreeBSD',
@@ -135,7 +129,6 @@ describe 'apache::mod::ssl', type: :class do
         osfamily: 'Gentoo',
         operatingsystem: 'Gentoo',
         operatingsystemrelease: '3.16.1-gentoo',
-        concat_basedir: '/dne',
         id: 'root',
         kernel: 'Linux',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/opt/bin',
@@ -154,7 +147,6 @@ describe 'apache::mod::ssl', type: :class do
         osfamily: 'Suse',
         operatingsystem: 'SLES',
         operatingsystemrelease: '12',
-        concat_basedir: '/dne',
         id: 'root',
         kernel: 'Linux',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/opt/bin',
@@ -175,7 +167,6 @@ describe 'apache::mod::ssl', type: :class do
         operatingsystemrelease: '6',
         kernel: 'Linux',
         id: 'root',
-        concat_basedir: '/dne',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
         is_pe: false,
       }
