@@ -6,9 +6,8 @@ describe 'apache::mod::wsgi', type: :class do
     let :facts do
       {
         osfamily: 'Debian',
-        operatingsystemrelease: '6',
-        concat_basedir: '/dne',
-        lsbdistcodename: 'squeeze',
+        operatingsystemrelease: '8',
+        lsbdistcodename: 'jessie',
         operatingsystem: 'Debian',
         id: 'root',
         kernel: 'Linux',
@@ -30,7 +29,6 @@ describe 'apache::mod::wsgi', type: :class do
       {
         osfamily: 'RedHat',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         operatingsystem: 'RedHat',
         id: 'root',
         kernel: 'Linux',
@@ -121,7 +119,6 @@ describe 'apache::mod::wsgi', type: :class do
       {
         osfamily: 'FreeBSD',
         operatingsystemrelease: '9',
-        concat_basedir: '/dne',
         operatingsystem: 'FreeBSD',
         id: 'root',
         kernel: 'FreeBSD',
@@ -144,7 +141,6 @@ describe 'apache::mod::wsgi', type: :class do
         osfamily: 'Gentoo',
         operatingsystem: 'Gentoo',
         operatingsystemrelease: '3.16.1-gentoo',
-        concat_basedir: '/dne',
         id: 'root',
         kernel: 'Linux',
         path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/opt/bin',
@@ -160,4 +156,36 @@ describe 'apache::mod::wsgi', type: :class do
     }
     it { is_expected.to contain_package('www-apache/mod_wsgi') }
   end
+  context 'overriding mod_libs' do
+    context 'on a RedHat OS', :compile do
+      let :facts do
+        {
+          id: 'root',
+          kernel: 'Linux',
+          osfamily: 'RedHat',
+          operatingsystem: 'Fedora',
+          operatingsystemrelease: '28',
+          path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
+          is_pe: false,
+        }
+      end
+      let :pre_condition do
+        <<-MANIFEST
+        include apache::params
+        class { 'apache':
+          mod_packages => merge($::apache::params::mod_packages, {
+            'wsgi' => 'python3-mod_wsgi',
+          }),
+          mod_libs => merge($::apache::params::mod_libs, {
+            'wsgi' => 'mod_wsgi_python3.so',
+          })
+        }
+        MANIFEST
+      end
+
+      it { is_expected.to contain_class('apache::params') }
+      it { is_expected.to contain_file('wsgi.load').with_content(%r{LoadModule wsgi_module modules/mod_wsgi_python3.so}) }
+      it { is_expected.to contain_package('python3-mod_wsgi') }
+    end
+  end
 end
