@@ -8,10 +8,9 @@ describe 'apache::balancermember', type: :define do
     {
       osfamily: 'Debian',
       operatingsystem: 'Debian',
-      operatingsystemrelease: '6',
-      lsbdistcodename: 'squeeze',
+      operatingsystemrelease: '8',
+      lsbdistcodename: 'jessie',
       id: 'root',
-      concat_basedir: '/dne',
       path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
       kernel: 'Linux',
       is_pe: false,
