@@ -20,7 +20,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '6',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -38,9 +37,8 @@ describe 'apache::vhost', type: :define do
       let :default_facts do
         {
           osfamily: 'Debian',
-          operatingsystemrelease: '6',
-          concat_basedir: '/dne',
-          lsbdistcodename: 'squeeze',
+          operatingsystemrelease: '8',
+          lsbdistcodename: 'jessie',
           operatingsystem: 'Debian',
           id: 'root',
           kernel: 'Linux',
@@ -72,7 +70,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'FreeBSD',
           operatingsystemrelease: '9',
-          concat_basedir: '/dne',
           operatingsystem: 'FreeBSD',
           id: 'root',
           kernel: 'FreeBSD',
@@ -98,7 +95,6 @@ describe 'apache::vhost', type: :define do
           osfamily: 'Gentoo',
           operatingsystem: 'Gentoo',
           operatingsystemrelease: '3.16.1-gentoo',
-          concat_basedir: '/dne',
           id: 'root',
           kernel: 'Linux',
           path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/opt/bin',
@@ -123,7 +119,6 @@ describe 'apache::vhost', type: :define do
       {
         osfamily: 'Debian',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         lsbdistcodename: 'squeeze',
         operatingsystem: 'Debian',
         id: 'root',
@@ -246,7 +241,7 @@ describe 'apache::vhost', type: :define do
             },
             { 'path'              => '/var/www/files/indexed_directory',
               'directoryindex'    => 'disabled',
-              'options'           => %w[Indexes FollowSymLinks MultiViews],
+              'options'           => ['Indexes', 'FollowSymLinks', 'MultiViews'],
               'index_options'     => ['FancyIndexing'],
               'index_style_sheet' => '/styles/style.css' },
             { 'path'              => '/var/www/files/output_filtered',
@@ -267,6 +262,46 @@ describe 'apache::vhost', type: :define do
               'dav'                => 'filesystem',
               'dav_depth_infinity' => true,
               'dav_min_timeout'    => '600' },
+            {
+              'path'                                                => '/var/www/node-app/public',
+              'passenger_enabled'                                   => true,
+              'passenger_base_uri'                                  => '/app',
+              'passenger_ruby'                                      => '/path/to/ruby',
+              'passenger_python'                                    => '/path/to/python',
+              'passenger_nodejs'                                    => '/path/to/nodejs',
+              'passenger_meteor_app_settings'                       => '/path/to/file.json',
+              'passenger_app_env'                                   => 'demo',
+              'passenger_app_root'                                  => '/var/www/node-app',
+              'passenger_app_group_name'                            => 'foo_bar',
+              'passenger_app_type'                                  => 'node',
+              'passenger_startup_file'                              => 'start.js',
+              'passenger_restart_dir'                               => 'temp',
+              'passenger_load_shell_envvars'                        => false,
+              'passenger_rolling_restarts'                          => false,
+              'passenger_resist_deployment_errors'                  => false,
+              'passenger_user'                                      => 'nodeuser',
+              'passenger_group'                                     => 'nodegroup',
+              'passenger_friendly_error_pages'                      => true,
+              'passenger_min_instances'                             => 7,
+              'passenger_max_instances'                             => 9,
+              'passenger_force_max_concurrent_requests_per_process' => 12,
+              'passenger_start_timeout'                             => 10,
+              'passenger_concurrency_model'                         => 'thread',
+              'passenger_thread_count'                              => 20,
+              'passenger_max_requests'                              => 2000,
+              'passenger_max_request_time'                          => 1,
+              'passenger_memory_limit'                              => 32,
+              'passenger_high_performance'                          => false,
+              'passenger_buffer_upload'                             => false,
+              'passenger_buffer_response'                           => false,
+              'passenger_error_override'                            => false,
+              'passenger_max_request_queue_size'                    => 120,
+              'passenger_max_request_queue_time'                    => 5,
+              'passenger_sticky_sessions'                           => true,
+              'passenger_sticky_sessions_cookie_name'               => '_delicious_cookie',
+              'passenger_allow_encoded_slashes'                     => false,
+              'passenger_debugger'                                  => false,
+            },
           ],
           'error_log'                   => false,
           'error_log_file'              => 'httpd_error_log',
@@ -289,7 +324,7 @@ describe 'apache::vhost', type: :define do
             {
               'path'            => '/a',
               'url'             => 'http://backend-a/',
-              'keywords'        => %w[noquery interpolate],
+              'keywords'        => ['noquery', 'interpolate'],
               'no_proxy_uris'       => ['/a/foo', '/a/bar'],
               'no_proxy_uris_match' => ['/a/foomatch'],
               'reverse_cookies' => [
@@ -313,7 +348,7 @@ describe 'apache::vhost', type: :define do
             {
               'path'     => '/a',
               'url'      => 'http://backend-a/',
-              'keywords' => %w[noquery interpolate],
+              'keywords' => ['noquery', 'interpolate'],
               'no_proxy_uris'       => ['/a/foo', '/a/bar'],
               'no_proxy_uris_match' => ['/a/foomatch'],
               'params' => {
@@ -326,8 +361,8 @@ describe 'apache::vhost', type: :define do
           'suphp_addhandler'            => 'foo',
           'suphp_engine'                => 'on',
           'suphp_configpath'            => '/var/www/html',
-          'php_admin_flags'             => %w[foo bar],
-          'php_admin_values'            => %w[true false],
+          'php_admin_flags'             => ['foo', 'bar'],
+          'php_admin_values'            => ['true', 'false'],
           'no_proxy_uris'               => '/foo',
           'no_proxy_uris_match'         => '/foomatch',
           'proxy_preserve_host'         => true,
@@ -339,8 +374,6 @@ describe 'apache::vhost', type: :define do
           'redirectmatch_status'        => ['404'],
           'redirectmatch_regexp'        => ['\.git$'],
           'redirectmatch_dest'          => ['http://www.example.com'],
-          'rack_base_uris'              => ['/rackapp1'],
-          'passenger_base_uris'         => ['/passengerapp1'],
           'headers'                     => 'Set X-Robots-Tag "noindex, noarchive, nosnippet"',
           'request_headers'             => ['append MirrorID "mirror 12"'],
           'rewrites'                    => [
@@ -402,19 +435,48 @@ describe 'apache::vhost', type: :define do
           'suexec_user_group'           => 'root root',
           'allow_encoded_slashes'       => 'nodecode',
           'use_canonical_name'          => 'dns',
-          'passenger_spawn_method'      => 'direct',
-          'passenger_app_root'          => '/usr/share/myapp',
-          'passenger_app_env'           => 'test',
-          'passenger_ruby'              => '/usr/bin/ruby1.9.1',
-          'passenger_min_instances'     => '1',
-          'passenger_max_requests'      => '1000',
-          'passenger_start_timeout'     => '600',
-          'passenger_pre_start'         => 'http://localhost/myapp',
-          'passenger_high_performance'  => true,
-          'passenger_user'              => 'sandbox',
-          'passenger_nodejs'            => '/usr/bin/node',
-          'passenger_sticky_sessions'   => true,
-          'passenger_startup_file'      => 'bin/www',
+          'passenger_enabled'                     => false,
+          'passenger_base_uri'                    => '/app',
+          'passenger_ruby'                        => '/usr/bin/ruby1.9.1',
+          'passenger_python'                      => '/usr/local/bin/python',
+          'passenger_nodejs'                      => '/usr/bin/node',
+          'passenger_meteor_app_settings'         => '/path/to/some/file.json',
+          'passenger_app_env'                     => 'test',
+          'passenger_app_root'                    => '/usr/share/myapp',
+          'passenger_app_group_name'              => 'app_customer',
+          'passenger_app_type'                    => 'rack',
+          'passenger_startup_file'                => 'bin/www',
+          'passenger_restart_dir'                 => 'tmp',
+          'passenger_spawn_method'                => 'direct',
+          'passenger_load_shell_envvars'          => false,
+          'passenger_rolling_restarts'            => false,
+          'passenger_resist_deployment_errors'    => true,
+          'passenger_user'                        => 'sandbox',
+          'passenger_group'                       => 'sandbox',
+          'passenger_friendly_error_pages'        => false,
+          'passenger_min_instances'               => 1,
+          'passenger_max_instances'               => 30,
+          'passenger_max_preloader_idle_time'     => 600,
+          'passenger_force_max_concurrent_requests_per_process' => 10,
+          'passenger_start_timeout'               => 600,
+          'passenger_concurrency_model'           => 'thread',
+          'passenger_thread_count'                => 5,
+          'passenger_max_requests'                => 1000,
+          'passenger_max_request_time'            => 2,
+          'passenger_memory_limit'                => 64,
+          'passenger_stat_throttle_rate'          => 5,
+          'passenger_pre_start'                   => 'http://localhost/myapp',
+          'passenger_high_performance'            => true,
+          'passenger_buffer_upload'               => false,
+          'passenger_buffer_response'             => false,
+          'passenger_error_override'              => true,
+          'passenger_max_request_queue_size'      => 10,
+          'passenger_max_request_queue_time'      => 2,
+          'passenger_sticky_sessions'             => true,
+          'passenger_sticky_sessions_cookie_name' => '_nom_nom_nom',
+          'passenger_allow_encoded_slashes'       => true,
+          'passenger_debugger'                    => true,
+          'passenger_lve_min_uid'                 => 500,
           'add_default_charset'         => 'UTF-8',
           'jk_mounts'                   => [
             { 'mount'   => '/*',     'worker' => 'tcnode1' },
@@ -437,7 +499,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -649,6 +710,191 @@ describe 'apache::vhost', type: :define do
           content: %r{^\s+DavMinTimeout\s600$},
         )
       }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerEnabled\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerBaseURI\s/app$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerRuby\s/path/to/ruby$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerPython\s/path/to/python$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerNodejs\s/path/to/nodejs$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMeteorAppSettings\s/path/to/file\.json$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerAppEnv\sdemo$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerAppRoot\s/var/www/node-app$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerAppGroupName\sfoo_bar$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerAppType\snode$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerStartupFile\sstart\.js$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerRestartDir\stemp$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerLoadShellEnvvars\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerRollingRestarts\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerResistDeploymentErrors\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerUser\snodeuser$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerGroup\snodegroup$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerFriendlyErrorPages\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMinInstances\s7$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMaxInstances\s9$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerForceMaxConcurrentRequestsPerProcess\s12$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerStartTimeout\s10$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerConcurrencyModel\sthread$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerThreadCount\s20$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMaxRequests\s2000$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMaxRequestTime\s1$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMemoryLimit\s32$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerHighPerformance\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerBufferUpload\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerBufferResponse\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerErrorOverride\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMaxRequestQueueSize\s120$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerMaxRequestQueueTime\s5$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerStickySessions\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerStickySessionsCookieName\s_delicious_cookie$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerAllowEncodedSlashes\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-directories').with(
+          content: %r{^\s+PassengerDebugger\sOff$},
+        )
+      }
       it { is_expected.to contain_concat__fragment('rspec.example.com-additional_includes') }
       it { is_expected.to contain_concat__fragment('rspec.example.com-logging') }
       it { is_expected.to contain_concat__fragment('rspec.example.com-serversignature') }
@@ -701,7 +947,6 @@ describe 'apache::vhost', type: :define do
           %r{ProxyPassReverseCookieDomain\s+foo\s+http:\/\/foo},
         )
       }
-      it { is_expected.to contain_concat__fragment('rspec.example.com-rack') }
       it { is_expected.to contain_concat__fragment('rspec.example.com-redirect') }
       it { is_expected.to contain_concat__fragment('rspec.example.com-rewrite') }
       it {
@@ -851,6 +1096,216 @@ describe 'apache::vhost', type: :define do
           content: %r{^\s+MaxKeepAliveRequests\s1000$},
         )
       }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerEnabled\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerBaseURI\s/app$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerRuby\s/usr/bin/ruby1\.9\.1$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerPython\s/usr/local/bin/python$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerNodejs\s/usr/bin/node$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMeteorAppSettings\s/path/to/some/file.json$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerAppEnv\stest$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerAppRoot\s/usr/share/myapp$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerAppGroupName\sapp_customer$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerAppType\srack$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerStartupFile\sbin/www$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerRestartDir\stmp$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerSpawnMethod\sdirect$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerLoadShellEnvvars\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerRollingRestarts\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerResistDeploymentErrors\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerUser\ssandbox$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerGroup\ssandbox$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerFriendlyErrorPages\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMinInstances\s1$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxInstances\s30$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxPreloaderIdleTime\s600$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerForceMaxConcurrentRequestsPerProcess\s10$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerStartTimeout\s600$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerConcurrencyModel\sthread$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerThreadCount\s5$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxRequests\s1000$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxRequestTime\s2$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMemoryLimit\s64$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerStatThrottleRate\s5$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-file_footer').with(
+          content: %r{^PassengerPreStart\shttp://localhost/myapp$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerHighPerformance\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerBufferUpload\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerBufferResponse\sOff$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerErrorOverride\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxRequestQueueSize\s10$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerMaxRequestQueueTime\s2$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerStickySessions\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerStickySessionsCookieName\s_nom_nom_nom$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerAllowEncodedSlashes\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerDebugger\sOn$},
+        )
+      }
+      it {
+        is_expected.to contain_concat__fragment('rspec.example.com-passenger').with(
+          content: %r{^\s+PassengerLveMinUid\s500$},
+        )
+      }
     end
     context 'vhost with multiple ip addresses' do
       let :params do
@@ -868,7 +1323,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -893,7 +1347,7 @@ describe 'apache::vhost', type: :define do
     context 'vhost with multiple ports' do
       let :params do
         {
-          'port'                        => %w[80 8080],
+          'port'                        => ['80', '8080'],
           'ip'                          => '127.0.0.1',
           'ip_based'                    => true,
           'servername'                  => 'example.com',
@@ -906,7 +1360,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -931,7 +1384,7 @@ describe 'apache::vhost', type: :define do
     context 'vhost with multiple ip addresses, multiple ports' do
       let :params do
         {
-          'port'                        => %w[80 8080],
+          'port'                        => ['80', '8080'],
           'ip'                          => ['127.0.0.1', '::1'],
           'ip_based'                    => true,
           'servername'                  => 'example.com',
@@ -944,7 +1397,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -986,7 +1438,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -1022,7 +1473,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -1150,7 +1600,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '6',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -1233,7 +1682,6 @@ describe 'apache::vhost', type: :define do
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-block') }
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-error_document') }
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-proxy') }
-      it { is_expected.not_to contain_concat__fragment('rspec.example.com-rack') }
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-redirect') }
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-rewrite') }
       it { is_expected.not_to contain_concat__fragment('rspec.example.com-scriptalias') }
@@ -1396,7 +1844,6 @@ describe 'apache::vhost', type: :define do
       {
         osfamily: 'RedHat',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         operatingsystem: 'RedHat',
         id: 'root',
         kernel: 'Linux',
@@ -1468,7 +1915,6 @@ describe 'apache::vhost', type: :define do
       {
         osfamily: 'RedHat',
         operatingsystemrelease: '6',
-        concat_basedir: '/dne',
         operatingsystem: 'RedHat',
         id: 'root',
         kernel: 'Linux',
@@ -1749,7 +2195,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -1785,7 +2230,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '7',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
@@ -1809,7 +2253,6 @@ describe 'apache::vhost', type: :define do
         {
           osfamily: 'RedHat',
           operatingsystemrelease: '6',
-          concat_basedir: '/dne',
           operatingsystem: 'RedHat',
           id: 'root',
           kernel: 'Linux',
